searchNodes=[{"doc":"This is the entry point for the Erebus library. Here you will find operations for both encrypting and decrypting fields in the database. Erebus is an implementation of the envelope encryption paradigm. For each encrypted struct, it uses a separate key called DEK (short for data encryption key). That key is encrypted using KEK (key encryption key). The DEK is a symmetric key (Erebus uses AES-256 with Galois mode (AES-GCM) with AEAD), which guarantees both security and integrity of the data. The KEK is an asymmetric key - Erebus uses the public key for encryption (for performance reasons when using external key storage) and the private for decryption. The specific implementation depends on the backend. Currently, there are three supported backend implementations: Erebus.KMS.Google - Google KMS key storage. Your private key never leaves Google infrastructure, which is the most secure option Erebus.KMS.Local - private/public key pair stored on your hard drive. Please note that it makes your keys prone to leakage Erebus.KMS.Dummy - base64 as encryption for DEK. Never use it in production Please note that you need to provide the config for the operations and call them, providing them for each call. The preferred way of running it is with your wrapper, like: defmodule MyApp.Erebus do def encrypt ( struct , handle , version ) do opts = Application . get_env ( :my_app , :erebus ) Erebus . encrypt ( struct , handle , version , opts ) end def decrypt ( ) do opts = Application . get_env ( :my_app , :erebus ) end end while providing config in your app config file, e.g. for Google KMS: config :my_app , :erebus , kms_backend : Erebus.KMS.Google , google_project : &quot;someproject&quot; , google_region : &quot;someregion&quot; , google_keyring : &quot;some_keyring&quot; , google_goth : MyApp.Goth or when using a local key file: config :my_app , :erebus , kms_backend : Erebus.KMS.Local , keys_base_path : &quot;/tmp/keys&quot; , private_key_password : &quot;1234&quot; This also enables you to use a different Erebus config for less important data (e.g. local keys) and the higher security Google KMS where you need it.","ref":"Erebus.html","title":"Erebus","type":"module"},{"doc":"This function decrypts your encrypted struct. It takes: encrypted struct with dek field present list of fields to be decrypted options - providing backend and options for that backend","ref":"Erebus.html#decrypt/3","title":"Erebus.decrypt/3","type":"function"},{"doc":"This function should be called when you want to encrypt your struct. It takes: struct which implements Erebus.Encryption protocol handle for key version of key options - providing backend and options for that backend One very meaningful option is :force_reencrypt flag, which can be used for re-encrypting all of the fields even when nothing was changed.","ref":"Erebus.html#encrypt/4","title":"Erebus.encrypt/4","type":"function"},{"doc":"reencrypt_dek, when called on an encrypted struct, forces re-encrypting the DEK using the provided KEK backend.","ref":"Erebus.html#reencrypt_dek/4","title":"Erebus.reencrypt_dek/4","type":"function"},{"doc":"This module stores data necessary for decrypting an encrypted struct. It stores: encrypted dek handle of the key used to encrypt it version of the key used to encrypt it","ref":"Erebus.EncryptedData.html","title":"Erebus.EncryptedData","type":"module"},{"doc":"","ref":"Erebus.EncryptedData.html#t:t/0","title":"Erebus.EncryptedData.t/0","type":"type"},{"doc":"","ref":"Erebus.Encryption.html","title":"Erebus.Encryption","type":"protocol"},{"doc":"Erebus.Encryption protocol lists the fields that need to be encrypted when encrypting a struct.","ref":"Erebus.Encryption.html#encrypted_fields/1","title":"Erebus.Encryption.encrypted_fields/1","type":"function"},{"doc":"","ref":"Erebus.Encryption.html#t:t/0","title":"Erebus.Encryption.t/0","type":"type"},{"doc":"This module is a proxy for a key backend","ref":"Erebus.KMS.html","title":"Erebus.KMS","type":"behaviour"},{"doc":"Decrypts DEK - provided in the form of Erebus.EncryptedData struct, using the provided backend.","ref":"Erebus.KMS.html#decrypt/2","title":"Erebus.KMS.decrypt/2","type":"function"},{"doc":"","ref":"Erebus.KMS.html#c:decrypt/2","title":"Erebus.KMS.decrypt/2","type":"callback"},{"doc":"Encrypts DEK - returns Erebus.EncryptedData struct with encrypted DEK, using given handle, version and backend.","ref":"Erebus.KMS.html#encrypt/4","title":"Erebus.KMS.encrypt/4","type":"function"},{"doc":"","ref":"Erebus.KMS.html#c:encrypt/4","title":"Erebus.KMS.encrypt/4","type":"callback"},{"doc":"Fetches the private key for the given handle and version for the given KMS backend (if it is supported).","ref":"Erebus.KMS.html#get_private_key/3","title":"Erebus.KMS.get_private_key/3","type":"function"},{"doc":"Fetches the public key for the given handle and version for the given KMS backend (if it is supported).","ref":"Erebus.KMS.html#get_public_key/3","title":"Erebus.KMS.get_public_key/3","type":"function"},{"doc":"This is a dummy implementation of the KEK backend. Never use it in production! It doesn't take any options. config :my_app , :erebus , kms_backend : Erebus.KMS.Dummy","ref":"Erebus.KMS.Dummy.html","title":"Erebus.KMS.Dummy","type":"module"},{"doc":"This KMS backend uses Google KMS to encrypt/decrypt DEKs. It requires a 2048 bit RSA key with OAEP Padding and SHA256 Digest. The used key/service account must have access to the following KMS roles : Cloud KMS CryptoKey Encrypter/Decrypter Cloud KMS CryptoKey Public Key Viewer When using this backend, please provide the following options: config :my_app , :erebus , kms_backend : Erebus.KMS.Google , google_project : &quot;someproject&quot; , google_region : &quot;someregion&quot; , google_keyring : &quot;some_keyring&quot; , google_goth : MyApp.Goth","ref":"Erebus.KMS.Google.html","title":"Erebus.KMS.Google","type":"module"},{"doc":"The Erebus.KMS.Local KMS backend uses a locally stored public/private key pair to encrypt/ decrypt DEKs. It requires 2048 bit RSA keys with OAEP Padding and SHA256 Digest. When using this backend, please provide the following options: config :my_app , :erebus , kms_backend : Erebus.KMS.Local , keys_base_path : &quot;some_path&quot; , private_key_password : &quot;1234&quot;","ref":"Erebus.KMS.Local.html","title":"Erebus.KMS.Local","type":"module"},{"doc":"This module serves as cache storage using ETS for private keys.","ref":"Erebus.PrivateKeyStore.html","title":"Erebus.PrivateKeyStore","type":"module"},{"doc":"Get the private key from the ETS cache OR fetch it from the backend - if the backend supports it.","ref":"Erebus.PrivateKeyStore.html#get_key/3","title":"Erebus.PrivateKeyStore.get_key/3","type":"function"},{"doc":"This module serves as cache storage using ETS for public keys.","ref":"Erebus.PublicKeyStore.html","title":"Erebus.PublicKeyStore","type":"module"},{"doc":"Get the public key from the ETS cache OR fetch it from the backend.","ref":"Erebus.PublicKeyStore.html#get_key/3","title":"Erebus.PublicKeyStore.get_key/3","type":"function"},{"doc":"This module provides macros for defining fields on your Ecto model. Usage: use Erebus.Schema use Ecto.Schema embedded_schema do hashed_encrypted_field ( :first ) data_encryption_key ( ) end","ref":"Erebus.Schema.html","title":"Erebus.Schema","type":"module"},{"doc":"Defines field dek of type map , which is required for storing encrypted information using Erebus. Please note that if you're using it with a database underneath, this field needs to be of type jsonb underneath.","ref":"Erebus.Schema.html#data_encryption_key/0","title":"Erebus.Schema.data_encryption_key/0","type":"macro"},{"doc":"Defines three fields: name : virtual field of type string name_encrypted : field of type binary storing encrypted data name_hash : field of type string , storing sha512 version of given data, for quick searching Please note that if you're using it with a database underneath, these fields need to be of type: name_encrypted : bytea name_hash : text","ref":"Erebus.Schema.html#hashed_encrypted_field/1","title":"Erebus.Schema.hashed_encrypted_field/1","type":"macro"},{"doc":"This module serves as cache storage using ETS for decrypted DEKs.","ref":"Erebus.SymmetricKeyStore.html","title":"Erebus.SymmetricKeyStore","type":"module"},{"doc":"Get DEK from the ETS cache OR decrypt it using provided KMS backend.","ref":"Erebus.SymmetricKeyStore.html#get_key/2","title":"Erebus.SymmetricKeyStore.get_key/2","type":"function"}]